
/***********************************************************************/
/*                                                                     */
/*  FILE        :DTL_control.c                                         */
/*  DATE        :22, Sept, 2020                                        */
/*  DESCRIPTION :Interrupt fuctions                                    */
/*  CPU TYPE    :RH series generic                                     */
/*                                                                     */
/***********************************************************************/


#if     defined(__ICCRX__)
  #include "r_cg_macrodriver.h"
  #include <math.h>
  #include "DTL_interrupt.h"
  #include "DTL_Custom_IO.h"
#elif   defined(__CCRX__)
  #include <machine.h>
  #include <mathf.h>
  #include <stdint.h>
  #include "iodefine.h"
  #include "DTL_interrupt.h"
  #include "DTL_Custom_IO.h"
#elif   defined(__CCRH__)
  #include <mathf.h>
  #include <stdint.h>
  #include "iodefine.h"
  #include "r_cg_macrodriver.h"
#endif


#include "DTL_IOLIB.h"
#include "DTL_control.h"


//========== Speed =============================================
float _fOe            = 0.0f;
float _fSpeedRpm      = 0.0f;
float _fSpeedRpmRef   = F_MOTOR_SPEED_REF;   // Start speed
float _fSpeedRpmRef2  = 0.0f;

float _fVdcLPF   = F_VDC_LPF;

//==============================================================
float _fVdRef = 0.0f;
float _fVqRef = 0.0f;

float _fVaRef = 0.0f;
float _fVbRef = 0.0f;

float _fVuRef = 0.0f;
float _fVvRef = 0.0f;
float _fVwRef = 0.0f;

float _fPe    = 0.0f;

//==============================================================
uint16_t _u2ModeSystem     = 0;     // 0:MODE_STOP,  1:MODE_RUN,   2:MODE_ERROR
uint16_t _u2FlagError      = 0;     // bit0:IacOC,   
uint16_t _u2POEStatus      = 0;
uint16_t _u2MotorTestOnOff = 0;     // Test mode = 1:Current closed loop
uint16_t _u2VopenMode      = 0;     // Test mode = 1:Voltage Open loop 

//= Motor parameters ===========================================
float _fRa   = F_MOTOR_RA;
float _fLd   = F_MOTOR_LD;
float _fLq   = F_MOTOR_LQ;
float _fKe   = F_MOTOR_KE;

//==============================================================
uint16_t  u2_timer_cnt = 0;

//= AD / AD Offset =============================================
float _fIacOCLevel    = F_ERROR_IAC_OC_LEVEL;
float _fVdcOVLevel    = F_ERROR_VDC_OV_LEVEL;
float _fVdcUVLevel    = F_ERROR_VDC_UV_LEVEL;

float _fIu1ADOffset   =  0.0f;
float _fIv1ADOffset   =  0.0f;
float _fIw1ADOffset   =  0.0f;

#define   OFFSET_CALC_TIMES    (128)
uint16_t _u2OffsetCalcTimes = 0;

float _fIu1ADOffsetSum  = 0.0f;
float _fIv1ADOffsetSum  = 0.0f;
float _fIw1ADOffsetSum  = 0.0f;


#define F_CARRIER_FREQ     (16000.0f)

uint16_t  _u2Carrier = 0;


void  DTL_carrier_control(void)
{
    if ((_u2Carrier&1)==0) { ics2_watchpoint(); }
  
    _u2Carrier = (_u2Carrier+1)&255;
}


void  DTL_timer_control(void)
{
    u2_timer_cnt++;
}


void  DTL_CAN_ICS_Timer(void)
{
    /* no code */
}


void  DTL_User_CustomIO_init(void)
{
    /* no code */
}
